pub enum ZkrSeedPoll {
Bist,
Wait,
Es16(u16),
Dead,
}Expand description
Result of polling the entropy source behind the Zkr extension’s seed CSR, corresponding to
one of the specification’s OPST states
Variants
Bist
Built-in self-test is being performed (OPST=BIST).
If this is returned after some other state was previously observed, it signals a non-fatal, but noteworthy, self-test alarm.
Wait
A sufficient amount of entropy is not yet available (OPST=WAIT).
This is not an error condition and may be observed more often than Self::Es16, since
physical entropy sources often have low bandwidth.
Es16(u16)
16 bits of randomness are available (OPST=ES16), guaranteed to meet the specification’s
minimum entropy requirements regardless of implementation.
Dead
An unrecoverable self-test error has occurred (OPST=DEAD).
Once returned, all future polls are expected to also return Self::Dead.