pub trait ZkrSeedSource {
// Required method
fn poll_seed(&mut self) -> ZkrSeedPoll;
}Expand description
Entropy source behind the Zkr extension’s seed CSR.
Every access to seed polls the entropy source once.
Required Methods
Sourcefn poll_seed(&mut self) -> ZkrSeedPoll
fn poll_seed(&mut self) -> ZkrSeedPoll
Poll the entropy source once, advancing its internal state as necessary
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".